==> alg-alg-1.56.60-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/rcmd2/AdxBidRet.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.rcmd2;

import lombok.Data;

@Data
public class AdxBidRet {

    /**
     * 创意计划ID
     */
    private Long ideaId;

    /**
     * 创意素材ID
     */
    private Long ideaUnitId;

    /**
     * 算法出价
     */
    private Long adxAlgoPrice;

    /**
     * 维稳因子
     */
    private Double factor;

    /**
     * 预估ctr
     */
    private Double preCtr;

    /**
     * 统计ctr
     */
    private Double statCtr;

    /**
     * 融合ctr
     */
    private Double ctr;

    /**
     * 预估每pv发券
     */
    private Double preLaunchPv;

    /**
     * 统计每pv发券
     */
    private Double statLaunchPv;

    /**
     * 融合每pv发券
     */
    private Double launchPv;

    /**
     * 点击价值
     */
    private Double clickValue;

    /**
     * 统计arpu值
     */
    private Double arpu;

    /**
     * 预估arpu值
     */
    private Double preArpu;

    /**
     * 融合arpu值
     */
    private Double mixArpu;

    /**
     * 精排排序分
     */
    private Double rankScore;

    /**
     * 探价因子分桶标记
     */
    private String level;

    /**
     * 投放状态：1=正常投放，2=广告位探量投放，3=计划冷启动探价
     */
    private Integer exploreType;

    /**
     * 底价/分
     */
    private Double basePrice;

    /**
     * 算法判断--计划创意来源池：true-冷启动池，false-优选池
     */
    private Boolean isNew;

    /**
     * 当前是否开启计划冷启动探价 0=关闭, 1-开启
     */
    private Boolean isColdStart;

    /**
     * 流量是否放弃（PD/PDB流量专用）
     * PD流量：0--不放弃；1--放弃
     * PDB流量：0--不放弃
     * RTB流量：不使用
     */
    private Integer isGiveUp;

}

==> alg-alg-1.56.74-sources.jar: cn/com/duiba/nezha/alg/alg/vo/adx/rcmd2/AdxBidRet.java <==
package cn.com.duiba.nezha.alg.alg.vo.adx.rcmd2;

import lombok.Data;

@Data
public class AdxBidRet {

    /**
     * 创意计划ID
     */
    private Long ideaId;

    /**
     * 创意素材ID
     */
    private Long ideaUnitId;

    /**
     * 算法出价
     */
    private Long adxAlgoPrice;

    /**
     * 维稳因子
     */
    private Double factor;

    /**
     * 预估ctr
     */
    private Double preCtr;

    /**
     * 统计ctr
     */
    private Double statCtr;

    /**
     * 融合ctr
     */
    private Double ctr;

    /**
     * 预估每pv发券
     */
    private Double preLaunchPv;

    /**
     * 统计每pv发券
     */
    private Double statLaunchPv;

    /**
     * 融合每pv发券
     */
    private Double launchPv;

    /**
     * 点击价值
     */
    private Double clickValue;

    /**
     * 统计arpu值
     */
    private Double arpu;

    /**
     * 预估arpu值
     */
    private Double preArpu;

    /**
     * 融合arpu值
     */
    private Double mixArpu;

    /**
     * 精排排序分
     */
    private Double rankScore;

    /**
     * 探价因子分桶标记
     */
    private String level;

    /**
     * 投放状态：1=正常投放，2=广告位探量投放，3=计划冷启动探价
     */
    private Integer exploreType;

    /**
     * 底价/分
     */
    private Double basePrice;

    /**
     * 算法判断--计划创意来源池：true-冷启动池，false-优选池
     */
    private Boolean isNew;

    /**
     * 当前是否开启计划冷启动探价 0=关闭, 1-开启
     */
    private Boolean isColdStart;

    /**
     * 流量是否放弃（PD/PDB流量专用）
     * PD流量：0--不放弃；1--放弃
     * PDB流量：0--不放弃
     * RTB流量：不使用
     */
    private Integer isGiveUp;

    //首发券相关

    /**
     * 首发券广告ID
     */
    private Long flcAdvertId;

    /**
     * 预估cvr
     */
    private Double preCvr;

    /**
     * 统计cvr
     */
    private Double statCvr;

    /**
     * 融合cvr
     */
    private Double mergeCvr;

    /**
     * 预估clickPv
     */
    private Double preClickPv;

    /**
     * 统计clickPv
     */
    private Double statClickPv;

    /**
     * 融合clickPv
     */
    private Double mergeClickPv;

    /**
     * 预估adCpc
     */
    private Double preAdCpc;

    /**
     * 统计adCpc
     */
    private Double statAdCpc;

    /**
     * 融合adCpc
     */
    private Double mergeAdCpc;

    /**
     * 融合 launchPv/clickPv
     */
    private Double launchOrClickPv;

    /**
     * 融合 arpu/adCpc
     */
    private Double arpuOrAdCpc;

}
